@@ -629,3 +629,17 @@ class Company(LinkedIn):
         LinkedIn.__init__(self)
         self.cookies = cookies
         self.headers = headers
+
+    def get_info(self, company_url):
+        req_url = f"{LINKEDIN_API}/company/getInfo?company_url={company_url}"
+        headers = {"Content-Type": "application/json"}
+        res = requests.post(req_url, json=self.cookies, headers=headers)
+        try:
+            res.raise_for_status()
+        except requests.HTTPError as e:
+            return e
+        else:
+            res_json = res.json()
+        for index in res_json.keys():
+            res_json[index] = [res_json[index]]
+        return pd.DataFrame(res_json).reset_index(drop=True)
